@@ -13,6 +13,7 @@ from command_tool.utils.utils import (
     ScanType,
     zip_folder,
     get_upload_zip_file,
+    debug_logger_level,
 )
 from command_tool.utils.user import show_user
 from command_tool.utils.login import login, create_scantist_token
@@ -97,7 +98,7 @@ def main():
     try:
         opts, args = getopt.getopt(
             argv,
-            "hblt:f:v:r:j:n:p:b:",
+            "hdblt:f:v:r:j:n:p:b:",
             [
                 "scan_type=",
                 "file_path=",
@@ -120,6 +121,8 @@ def main():
         if opt == "-h":
             logger.info(HELP_CONTENT)
             sys.exit()
+        elif opt == "-d":
+            debug_logger_level()
         elif opt in ("-t", "--scan_type"):
             scan_type = arg
         elif opt in ("-f", "--file"):
